@@ -5,7 +5,7 @@ import collections
 import pprint
 
 
-__version__ = '0.0.3'
+__version__ = '0.0.4'
 
 
 class Error(Exception):
@@ -49,6 +49,31 @@ def list_2d(n_row, n_column):
             in range(n_row)]
 
 
+def make_fixed_format_parser(fields):
+    """
+    fields: (('density', 3, int),
+             ('opacity', 7, float))
+    """
+    lower = 0
+    _fields = []
+    for field in fields:
+        if len(field) != 3:
+            exit('len(field) != 3 {}'.format(field))
+        name, length, converter = field
+        assert length >= 1
+        upper = lower + length
+        _field = (name, lower, upper, converter)
+        lower = upper
+        _fields.append(_field)
+
+    def fixed_format_parser(s):
+        assert len(s) >= upper
+        return {name: converter(s[lower:upper])
+                for name, lower, upper, converter
+                in _fields}
+    return fixed_format_parser
+
+
 class TestAction(argparse.Action):
     def __init__(self,
                  option_strings,
@@ -67,7 +92,7 @@ class TestAction(argparse.Action):
         parser.exit()
 
 
-class _Tester(unittest.TestCase):
+class Tester(unittest.TestCase):
     def test_list_2d(self):
         self.assertEqual(list_2d(2, 3),
                          [[None, None, None],
@@ -81,22 +106,23 @@ class _Tester(unittest.TestCase):
         self.assertEqual(tuple(sorted(flatten((1, 2, (3, [4, set([5, 6]), 7 ], [8, 9]))))),
                          tuple(sorted((1, 2, 3, 4, 5, 6, 7, 8, 9))))
 
-
-def _parse_arguments(args=sys.argv[1:]):
-    parser = argparse.ArgumentParser(description='Read a simple Makefile and write a dot file')
-    parser.add_argument('--test',
-                        action=TestAction,
-                        help='run tests')
-    parser.add_argument('--version',
-                        action='version',
-                        version='%(prog)s {version}'.format(version=__version__))
-
-    return parser.parse_args(args)
-
-
-def main(args=sys.argv[1:]):
-    _parse_arguments(args)
+    def test_make_fixed_format_parser(self):
+        with self.assertRaises(AssertionError):
+            make_fixed_format_parser((('a', 0, int),))
+        fixed_format_parser\
+            = make_fixed_format_parser((('a', 3, int),
+                                        ('b', 7, lambda x: -int(x))))
+        self.assertEqual(fixed_format_parser(' 325      '),
+                         {'a': 32, 'b': -5})
+        self.assertEqual(fixed_format_parser(' 325      \n'),
+                         {'a': 32, 'b': -5})
+        self.assertEqual(fixed_format_parser(' 32  5    '),
+                         {'a': 32, 'b': -5})
+        self.assertEqual(fixed_format_parser('32   5    abc'),
+                         {'a': 32, 'b': -5})
+        with self.assertRaises(AssertionError):
+            fixed_format_parser('123456789')
 
 
 if __name__ == '__main__':
-    main(sys.argv[1:])
+    unittest.main()
